==> grpc_0.11.1.orig.tar.gz: grpc-0.11.1/src/csharp/Grpc.Core/KeyCertificatePair.cs <==
#region Copyright notice and license

// Copyright 2015, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#endregion

using System;
using System.Collections.Generic;

using Grpc.Core.Internal;
using Grpc.Core.Utils;

namespace Grpc.Core
{
    /// <summary>
    /// Key certificate pair (in PEM encoding).
    /// </summary>
    public sealed class KeyCertificatePair
    {
        readonly string certificateChain;
        readonly string privateKey;

        /// <summary>
        /// Creates a new certificate chain - private key pair.
        /// </summary>
        /// <param name="certificateChain">PEM encoded certificate chain.</param>
        /// <param name="privateKey">PEM encoded private key.</param>
        public KeyCertificatePair(string certificateChain, string privateKey)
        {
            this.certificateChain = Preconditions.CheckNotNull(certificateChain, "certificateChain");
            this.privateKey = Preconditions.CheckNotNull(privateKey, "privateKey");
        }

        /// <summary>
        /// PEM encoded certificate chain.
        /// </summary>
        public string CertificateChain
        {
            get
            {
                return certificateChain;
            }
        }

        /// <summary>
        /// PEM encoded private key.
        /// </summary>
        public string PrivateKey
        {
            get
            {
                return privateKey;
            }
        }
    }
}

==> grpc_1.3.2.orig.tar.gz: grpc-1.3.2/src/csharp/Grpc.Core/KeyCertificatePair.cs <==
#region Copyright notice and license

// Copyright 2015, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#endregion

using System;
using System.Collections.Generic;

using Grpc.Core.Internal;
using Grpc.Core.Utils;

namespace Grpc.Core
{
    /// <summary>
    /// Key certificate pair (in PEM encoding).
    /// </summary>
    public sealed class KeyCertificatePair
    {
        readonly string certificateChain;
        readonly string privateKey;

        /// <summary>
        /// Creates a new certificate chain - private key pair.
        /// </summary>
        /// <param name="certificateChain">PEM encoded certificate chain.</param>
        /// <param name="privateKey">PEM encoded private key.</param>
        public KeyCertificatePair(string certificateChain, string privateKey)
        {
            this.certificateChain = GrpcPreconditions.CheckNotNull(certificateChain, "certificateChain");
            this.privateKey = GrpcPreconditions.CheckNotNull(privateKey, "privateKey");
        }

        /// <summary>
        /// PEM encoded certificate chain.
        /// </summary>
        public string CertificateChain
        {
            get
            {
                return certificateChain;
            }
        }

        /// <summary>
        /// PEM encoded private key.
        /// </summary>
        public string PrivateKey
        {
            get
            {
                return privateKey;
            }
        }
    }
}
